pub type AllPalletsWithSystem = (System, PalletFoo, PalletAuthor);Expand description
All pallets included in the runtime as a nested tuple of types.
pub type AllPalletsWithSystem = (System, PalletFoo, PalletAuthor);All pallets included in the runtime as a nested tuple of types.